@@ -22,6 +22,7 @@ def imshow_with_models(
     figsize=(8, 3),
     label="inside",
     label_textkw={},
+    filename=None,
     **kw,
 ):
     """
@@ -159,3 +160,5 @@ def imshow_with_models(
     if label:
         _add_panel_labels(ax[row_data, :], preset=label, **label_textkw)
     plt.sca(ax[row_data, 0])
+    if filename is not None:
+        self.savefig(filename)
